MoaT-GPIO
=========

This program controls GPIO lines via AMQP.
Currently it supports basic Linux GPIO features, i.e. input, output, and line monitoring.

TODO: input, i.e. passive interrogation of GPIO lines, isn't yet implemented.
(Monitoring does work.)

Home page: `MoaT-GPIO <https://github.com/M-o-a-T/moat-gpio>`__

License: Your choice of MIT or Apache License 2.0
